.. _spkg_sagemath_tdlib:

==================================================================================
sagemath_tdlib: Tree decompositions with tdlib
==================================================================================

About SageMath
--------------

   "Creating a Viable Open Source Alternative to
    Magma, Maple, Mathematica, and MATLAB"

   Copyright (C) 2005-2024 The Sage Development Team

   https://www.sagemath.org

SageMath fully supports all major Linux distributions, recent versions of
macOS, and Windows (Windows Subsystem for Linux).

See https://doc.sagemath.org/html/en/installation/index.html
for general installation instructions.


About this pip-installable source distribution
----------------------------------------------

This pip-installable source distribution ``sagemath-tdlib`` is a small
optional distribution for use with ``sagemath-standard``.

It provides a Cython interface to the ``tdlib`` library, providing
algorithms concerning tree decompositions.

Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_boost_cropped`
- :ref:`spkg_cysignals`
- :ref:`spkg_cython`
- :ref:`spkg_pkgconfig`
- :ref:`spkg_sage_setup`
- :ref:`spkg_sagemath_environment`
- :ref:`spkg_tdlib`

Version Information
-------------------

package-version.txt::

    10.4.63

version_requirements.txt::

    passagemath-tdlib ~= 10.4.63.0


Equivalent System Packages
--------------------------

(none known)

